@@ -7,12 +7,14 @@ library(filesstrings)
 ## ---- move files---------------------------------------------------------
 setwd(tempdir())
 dir.create("tmp_00")
-file.create("tmp000.txt")
+file.create("tmp000.txt", "tmp001.txt")
 list.files()
-PutFilesInDir("tmp000.txt", "tmp_00")
+MoveFiles("tmp000.txt", "tmp_00")
 list.files()
 list.files("tmp_00")
-unlink("tmp_00", recursive = TRUE)
+PutFilesInDir("tmp001.txt", "new_dir")  # This function creates the directory new_dir and then puts the files in the first argument in there
+list.files()
+unlink(c("tmp_00", "new_dir"), recursive = TRUE)
 
 ## ---- delete directory---------------------------------------------------
 setwd(tempdir())
